==> mahara_1.4.2.orig.tar.gz: mahara-1.4.2/htdocs/artefact/plans/lang/en.utf8/artefact.plans.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

/* Plans */
$string['canteditdontownplan'] = 'You can\'t edit this plan because you don\'t own it.';
$string['description'] = 'Description';
$string['deleteplanconfirm'] = 'Are you sure you wish to delete this plan? Deleting this plan will also remove any tasks it contains.';
$string['deleteplan'] = 'Delete plan';
$string['deletethisplan'] = 'Delete plan: \'%s\'';
$string['editplan'] = 'Edit Plan';
$string['editingplan'] = 'Editing Plan';
$string['managetasks'] = 'Manage tasks';
$string['newplan'] = 'New plan';
$string['noplansaddone'] = 'No plans yet. %sAdd one%s!';
$string['noplans'] = 'No plans to display';
$string['plan'] = 'Plan';
$string['plans'] = 'Plans';
$string['Plans'] = 'Plans';
$string['plandeletedsuccessfully'] = 'Plan deleted successfully.';
$string['plannotdeletedsuccessfully'] = 'There was an error deleting plan.';
$string['plannotsavedsuccessfully'] = 'There was an error submitting this form. Please check the marked fields and try again.';
$string['plansavedsuccessfully'] = 'Plan saved successfully.';
$string['planstasks'] = 'Plan \'%s\' tasks.';
$string['planstasksdesc'] = 'Add tasks below or using the button to the right to begin to build your plan.';
$string['saveplan'] = 'Save plan';
$string['title'] = 'Title';
$string['titledesc'] = 'The title will be used to display each task in the Plans blocktype.';

/* Tasks */
$string['alltasks'] = 'All tasks';
$string['canteditdontowntask'] = 'You can\'t edit this task because you don\'t own it.';
$string['completed'] = 'Completed';
$string['completiondate'] = 'Completion date';
$string['completeddesc'] = 'Mark your task completed.';
$string['deletetaskconfirm'] = 'Are you sure you wish to delete this task?';
$string['deletetask'] = 'Delete task';
$string['deletethistask'] = 'Delete task: \'%s\'';
$string['edittask'] = 'Edit task';
$string['editingtask'] = 'Editing task';
$string['mytasks'] = 'My Tasks';
$string['newtask'] = 'New task';
$string['notasks'] = 'No tasks to display.';
$string['notasksaddone'] = 'No tasks yet. %sAdd one%s!';
$string['savetask'] = 'Save task';
$string['task'] = 'task';
$string['tasks'] = 'tasks';
$string['taskdeletedsuccessfully'] = 'Task deleted successfully.';
$string['tasksavedsuccessfully'] = 'Task saved successfully.';

==> mahara_1.5.1.orig.tar.gz: mahara-1.5.1/htdocs/artefact/plans/lang/en.utf8/artefact.plans.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

/* Plans */
$string['canteditdontownplan'] = 'You can\'t edit this plan because you don\'t own it.';
$string['description'] = 'Description';
$string['deleteplanconfirm'] = 'Are you sure you wish to delete this plan? Deleting this plan will also remove any tasks it contains.';
$string['deleteplan'] = 'Delete plan';
$string['deletethisplan'] = 'Delete plan: \'%s\'';
$string['editplan'] = 'Edit Plan';
$string['editingplan'] = 'Editing Plan';
$string['managetasks'] = 'Manage tasks';
$string['newplan'] = 'New plan';
$string['noplansaddone'] = 'No plans yet. %sAdd one%s!';
$string['noplans'] = 'No plans to display';
$string['plan'] = 'Plan';
$string['plans'] = 'Plans';
$string['Plans'] = 'Plans';
$string['plandeletedsuccessfully'] = 'Plan deleted successfully.';
$string['plannotdeletedsuccessfully'] = 'There was an error deleting this plan.';
$string['plannotsavedsuccessfully'] = 'There was an error submitting this form. Please check the marked fields and try again.';
$string['plansavedsuccessfully'] = 'Plan saved successfully.';
$string['planstasks'] = 'Plan \'%s\' tasks.';
$string['planstasksdesc'] = 'Add tasks below or use the "Add" button to the right to begin to build your plan.';
$string['saveplan'] = 'Save plan';
$string['title'] = 'Title';
$string['titledesc'] = 'The title will be used to display each task in the plans blocktype.';

/* Tasks */
$string['alltasks'] = 'All tasks';
$string['canteditdontowntask'] = 'You can\'t edit this task because you don\'t own it.';
$string['completed'] = 'Completed';
$string['completiondate'] = 'Completion date';
$string['completeddesc'] = 'Mark your task completed.';
$string['deletetaskconfirm'] = 'Are you sure you wish to delete this task?';
$string['deletetask'] = 'Delete task';
$string['deletethistask'] = 'Delete task: \'%s\'';
$string['edittask'] = 'Edit task';
$string['editingtask'] = 'Editing task';
$string['mytasks'] = 'My tasks';
$string['newtask'] = 'New task';
$string['notasks'] = 'No tasks to display.';
$string['notasksaddone'] = 'No tasks yet. %sAdd one%s.';
$string['savetask'] = 'Save task';
$string['task'] = 'task';
$string['tasks'] = 'tasks';
$string['taskdeletedsuccessfully'] = 'Task deleted successfully.';
$string['tasksavedsuccessfully'] = 'Task saved successfully.';
